@@ -7,12 +7,12 @@ class FileWriter(Writer):
     def __init__(self, file_path):
         self.__path = file_path
 
-        super(FileWriter, self).__init__()
+        super().__init__()
 
     def flush(self):
         with open(self.__path, "w") as fout:
             for line in self.lines:
-                if line[-1:] != "\n":
+                if not line.endswith("\n"):
                     line += "\n"
 
                 fout.write(line)
@@ -27,10 +27,12 @@ class PrintWriter(Writer):
 class FileReader(Reader):
 
     def __init__(self, file_path):
+        # pylint: disable-next=consider-using-with
         self.iterable_object = open(file_path.replace('"', ""), "r")
+        # pylint: disable-next=unused-private-member
         self.__finalizer = weakref.finalize(self, lambda x: x.close(), self.iterable_object)
 
-        super(FileReader, self).__init__()
+        super().__init__()
 
 
 class LinesReader(Reader):
@@ -38,4 +40,4 @@ class LinesReader(Reader):
     def __init__(self, lines):
         self.iterable_object = lines.split("\n")
 
-        super(LinesReader, self).__init__()
+        super().__init__()
