@@ -78,6 +78,7 @@ def operation_replacer(method):
             aggs = aggrs.values()
         else:
             name = args[0] if args else kwargs.get('name')
+            # pylint: disable-next=unidiomatic-typecheck
             if type(obj.column_name) is _Operation and name is None:
                 raise ValueError('Output field name must be specified when aggregating operation')
             aggs = [obj]
@@ -85,6 +86,7 @@ def operation_replacer(method):
         # Add operation from each aggregation object to source `res` as column
         # and replace *column_name* property in each aggregation object with this column's name.
         for i, agg in enumerate(aggs):
+            # pylint: disable-next=unidiomatic-typecheck
             if type(agg.column_name) is _Operation:
                 tmp_name = f'__TMP_AGG_COLUMN_{i}__'
                 res[tmp_name] = agg.column_name
@@ -242,7 +244,7 @@ class _Aggregation(ABC):
         """
         Abstract method that implements common logic for aggregations
         """
-        if type(column) is list:
+        if isinstance(column, list):
             column = ','.join(map(str, column))
 
         column_name: Union[str, _Operation] = str(column)
@@ -251,6 +253,7 @@ class _Aggregation(ABC):
             # TODO: need to understand how to better work with alias
             column_name = "TIMESTAMP"
 
+        # pylint: disable-next=unidiomatic-typecheck
         if type(column) is _Operation:
             column_name = column
 
@@ -314,7 +317,7 @@ class _Aggregation(ABC):
         self.end_condition_per_group = end_condition_per_group
         self.boundary_tick_bucket = boundary_tick_bucket
         self.large_ints = False
-        if isinstance(group_by, _Operation) or isinstance(group_by, str):
+        if isinstance(group_by, (_Operation, str)):
             group_by = [group_by]
         self.group_by = group_by or []
         self.groups_to_display = groups_to_display
@@ -327,7 +330,7 @@ class _Aggregation(ABC):
     def _attr2str(value) -> str:
         if isinstance(value, bool):
             return 'true' if value else 'false'
-        if type(value) is list:
+        if isinstance(value, list):
             return ','.join(value)
         return str(value)
 
@@ -436,7 +439,7 @@ class _Aggregation(ABC):
     @staticmethod
     def validate_output_name(schema: Dict, name: Union[List, str]):
         """checks that aggregation won't output columns with same names"""
-        if type(name) is not list:
+        if not isinstance(name, list):
             name = [name]
 
         same_fields = []
