@@ -522,6 +522,17 @@ _size_max_fractional_digits_doc = param_doc(
     annotation=int,
     default=0,
 )
+_include_market_order_ticks_doc = param_doc(
+    name='include_market_order_ticks',
+    desc="""
+    If set, market order ticks (they have price NaN) are included into the order book,
+    and are at the order book's top level.
+
+        Default is False.
+    """,
+    annotation=bool,
+    default=None,
+)
 _query_fun_doc = param_doc(
     name='query_fun',
     desc="""
