@@ -36,7 +36,8 @@ from ._docs import (_running_doc,
                     _book_delimiters_doc,
                     _max_initialization_days_doc,
                     _state_key_max_inactivity_sec_doc,
-                    _size_max_fractional_digits_doc)
+                    _size_max_fractional_digits_doc,
+                    _include_market_order_ticks_doc)
 
 
 OB_SNAPSHOT_DOC_PARAMS = [
@@ -47,7 +48,8 @@ OB_SNAPSHOT_DOC_PARAMS = [
     _book_uncross_method_doc, _dq_events_that_clear_book_doc, _identify_source_doc,
     _show_full_detail_doc, _show_only_changes_doc, _book_delimiters_doc,
     _max_initialization_days_doc, _state_key_max_inactivity_sec_doc,
-    _size_max_fractional_digits_doc
+    _size_max_fractional_digits_doc,
+    _include_market_order_ticks_doc,
 ]
 OB_SNAPSHOT_WIDE_DOC_PARAMS = [
     _running_doc,
@@ -57,7 +59,8 @@ OB_SNAPSHOT_WIDE_DOC_PARAMS = [
     _book_uncross_method_doc, _dq_events_that_clear_book_doc,
     _book_delimiters_doc,
     _max_initialization_days_doc, _state_key_max_inactivity_sec_doc,
-    _size_max_fractional_digits_doc
+    _size_max_fractional_digits_doc,
+    _include_market_order_ticks_doc,
 ]
 OB_SNAPSHOT_FLAT_DOC_PARAMS = [
     _running_doc,
@@ -67,7 +70,8 @@ OB_SNAPSHOT_FLAT_DOC_PARAMS = [
     _book_uncross_method_doc, _dq_events_that_clear_book_doc,
     _show_full_detail_doc,
     _max_initialization_days_doc, _state_key_max_inactivity_sec_doc,
-    _size_max_fractional_digits_doc
+    _size_max_fractional_digits_doc,
+    _include_market_order_ticks_doc,
 ]
 OB_SUMMARY_DOC_PARAMS = [
     _running_doc,
@@ -75,7 +79,8 @@ OB_SUMMARY_DOC_PARAMS = [
     _bucket_end_condition_doc, _end_condition_per_group_doc, _group_by_doc, _groups_to_display_doc,
     _side_doc, _max_levels_doc, _min_levels_doc, _max_depth_shares_doc, _max_depth_for_price_doc,
     _book_uncross_method_doc, _dq_events_that_clear_book_doc, _max_initialization_days_doc,
-    _state_key_max_inactivity_sec_doc, _size_max_fractional_digits_doc
+    _state_key_max_inactivity_sec_doc, _size_max_fractional_digits_doc,
+    _include_market_order_ticks_doc,
 ]
 
 OB_SIZE_DOC_PARAMS = [
@@ -141,6 +146,8 @@ class _OrderBookAggregation(_Aggregation, ABC):
         self.max_initialization_days = max_initialization_days
         self.book_uncross_method = book_uncross_method
         self.dq_events_that_clear_book = ','.join(dq_events_that_clear_book) if dq_events_that_clear_book else None
+        self.bound_symbols = None
+
         super().__init__(_Column('TIMESTAMP'), *args, **kwargs)
 
     def _param_validation(self):
@@ -165,6 +172,19 @@ class _OrderBookAggregation(_Aggregation, ABC):
             raise TypeError(f"Aggregation `{self.NAME}` need these columns: "
                             f"BUY_SELL_FLAG, PRICE, SIZE and (UPDATE_TIME or DELETED_TIME)")
 
+    def to_ep(self, *args, **kwargs):
+        ob_ep = super().to_ep(*args, **kwargs)
+        if self.bound_symbols:
+            ob_ep = ob_ep.symbols(self.bound_symbols)
+
+        return ob_ep
+
+    def set_bound_symbols(self, bound_symbols=None):
+        if isinstance(bound_symbols, str):
+            bound_symbols = [bound_symbols]
+
+        self.bound_symbols = bound_symbols
+
 
 class ObSnapshot(_OrderBookAggregation):
     NAME = 'OB_SNAPSHOT'
@@ -177,6 +197,7 @@ class ObSnapshot(_OrderBookAggregation):
         'book_delimiters': 'BOOK_DELIMITERS',
         'state_key_max_inactivity_sec': 'STATE_KEY_MAX_INACTIVITY_SEC',
         'size_max_fractional_digits': 'SIZE_MAX_FRACTIONAL_DIGITS',
+        'include_market_order_ticks': 'INCLUDE_MARKET_ORDER_TICKS',
     })
     FIELDS_DEFAULT = dict(_OrderBookAggregation.FIELDS_DEFAULT, **{
         'identify_source': False,
@@ -185,6 +206,7 @@ class ObSnapshot(_OrderBookAggregation):
         'book_delimiters': None,
         'state_key_max_inactivity_sec': None,
         'size_max_fractional_digits': 0,
+        'include_market_order_ticks': None,
     })
 
     def __init__(self,
@@ -195,6 +217,7 @@ class ObSnapshot(_OrderBookAggregation):
                  book_delimiters: Optional[Literal['D']] = None,
                  state_key_max_inactivity_sec: Optional[int] = None,
                  size_max_fractional_digits: int = 0,
+                 include_market_order_ticks: Optional[bool] = None,
                  **kwargs):
         self.identify_source = identify_source
         self.show_full_detail = show_full_detail
@@ -202,11 +225,22 @@ class ObSnapshot(_OrderBookAggregation):
         self.book_delimiters = book_delimiters
         self.state_key_max_inactivity_sec = state_key_max_inactivity_sec
         self.size_max_fractional_digits = size_max_fractional_digits
+        self.include_market_order_ticks = include_market_order_ticks
         # we don't want to set hard limit on the output of order book aggregations
         if self.show_full_detail:
             kwargs['all_fields'] = True
         super().__init__(*args, **kwargs)
 
+    def _param_validation(self):
+        super()._param_validation()
+        if self.include_market_order_ticks is not None:
+            if 'include_market_order_ticks' not in self.EP.Parameters.list_parameters():
+                raise ValueError("Parameter 'include_market_order_ticks' is not supported on this OneTick API version")
+            otp.compatibility.is_include_market_order_ticks_supported(
+                throw_warning=True,
+                feature_name="parameter 'include_market_order_ticks'",
+            )
+
     def _get_output_schema(self, src: 'Source', name: Optional[str] = None) -> dict:
         schema = {
             'PRICE': float,
@@ -284,11 +318,13 @@ class ObSummary(_OrderBookAggregation):
         'min_levels': 'MIN_LEVELS',
         'state_key_max_inactivity_sec': 'STATE_KEY_MAX_INACTIVITY_SEC',
         'size_max_fractional_digits': 'SIZE_MAX_FRACTIONAL_DIGITS',
+        'include_market_order_ticks': 'INCLUDE_MARKET_ORDER_TICKS',
     })
     FIELDS_DEFAULT = dict(_OrderBookAggregation.FIELDS_DEFAULT, **{
         'min_levels': None,
         'state_key_max_inactivity_sec': None,
         'size_max_fractional_digits': 0,
+        'include_market_order_ticks': None,
     })
 
     def __init__(self,
@@ -296,6 +332,7 @@ class ObSummary(_OrderBookAggregation):
                  min_levels: Optional[int] = None,
                  state_key_max_inactivity_sec: Optional[int] = None,
                  size_max_fractional_digits: int = 0,
+                 include_market_order_ticks: Optional[bool] = None,
                  **kwargs):
         if is_supported_otq_ob_summary():
             self.EP = otq.ObSummary
@@ -305,8 +342,19 @@ class ObSummary(_OrderBookAggregation):
         self.min_levels = min_levels
         self.state_key_max_inactivity_sec = state_key_max_inactivity_sec
         self.size_max_fractional_digits = size_max_fractional_digits
+        self.include_market_order_ticks = include_market_order_ticks
         super().__init__(*args, **kwargs)
 
+    def _param_validation(self):
+        super()._param_validation()
+        if self.include_market_order_ticks is not None:
+            if 'include_market_order_ticks' not in self.EP.Parameters.list_parameters():
+                raise ValueError("Parameter 'include_market_order_ticks' is not supported on this OneTick API version")
+            otp.compatibility.is_include_market_order_ticks_supported(
+                throw_warning=True,
+                feature_name="parameter 'include_market_order_ticks'",
+            )
+
     def _get_output_schema(self, src: 'Source', name: Optional[str] = None) -> dict:
         schema = {
             'BID_SIZE': int,
