@@ -750,3 +750,27 @@ def is_ilike_supported():
     # 20250423: Implemented 0035413: Add support of ILIKE in SQL
     return _is_min_build_or_version(None, None,
                                     20250510120000)
+
+
+def is_include_market_order_ticks_supported(**kwargs):
+    # Implemented 0031478: OB_SNAPSHOT... and OB_SUMMARY EPs
+    # should support parameter INCLUDE_MARKET_ORDER_TICKS (false by default)
+    return _is_min_build_or_version(1.25, 20241229055942,
+                                    20240812120000, min_update_number=2,
+                                    **kwargs)
+
+
+def is_join_with_query_symbol_time_otq_supported():
+    # 20241209: Fixed 0034770: hours/minutes/seconds part of otq parameter _SYMBOL_TIME, expressed in
+    # milliseconds since 1970/01/01 00:00:00 GMT, is ignored
+    # 20250219: Implemented 0035092: passing otq param _SYMBOL_TIME should be just like setting symbol_date
+    # to the equivalent value, except in YYYYMMDDhhmmss format
+    return _is_min_build_or_version(None, None,
+                                    20250227120000)
+
+
+def is_show_db_list_show_description_supported():
+    # 20240301: Implemented 0032320: 0032320: SHOW_DB_LIST should have a new EP parameter, SHOW_DESCRIPTION
+    # However on 20240330 builds it returns SHOW_DESCRIPTION column instead of DESCRIPTION
+    return _is_min_build_or_version(1.25, 20241229055942,
+                                    20240501000000)
