@@ -1,6 +1,5 @@
 import warnings
-from inspect import Parameter
-from typing import TYPE_CHECKING, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Tuple, Union
 
 from onetick import py as otp
 from onetick.py import aggregations
@@ -397,8 +396,8 @@ def distinct(self: 'Source', *args, **kwargs):
     """
     if 'bucket_interval_units' in kwargs:
         kwargs['bucket_units'] = kwargs.pop('bucket_interval_units')
-    agg = aggregations.functions.distinct(*args, **kwargs)
-    return agg.apply(self)
+    aggr = aggregations.functions.distinct(*args, **kwargs)
+    return aggr.apply(self)
 
 
 # mimic=False for backward compatibility
@@ -421,8 +420,8 @@ def high_time(self: 'Source', *args, **kwargs):
         FutureWarning,
         stacklevel=2,
     )
-    agg = aggregations.functions.high_time(*args, **kwargs)
-    return agg.apply(self, 'VALUE')
+    aggr = aggregations.functions.high_time(*args, **kwargs)
+    return aggr.apply(self, 'VALUE')
 
 
 # mimic=False for backward compatibility
@@ -445,8 +444,8 @@ def low_time(self: 'Source', *args, **kwargs):
         FutureWarning,
         stacklevel=2,
     )
-    agg = aggregations.functions.low_time(*args, **kwargs)
-    return agg.apply(self, 'VALUE')
+    aggr = aggregations.functions.low_time(*args, **kwargs)
+    return aggr.apply(self, 'VALUE')
 
 
 @copy_method(aggregations.functions.ob_snapshot)
@@ -800,7 +799,7 @@ def process_by_group(
             output_schema[field] = input_schema[field]
         for field, field_type in output_schema.items():
             output_source.schema[field] = field_type
-        output_source = output_source[[field for field in output_schema]]
+        output_source = output_source[list(output_schema)]
         output_source._merge_tmp_otq(main_source)
         output_sources.append(output_source)
 
