@@ -329,7 +329,7 @@ class Expression:
     @property
     def is_dynamic_tick(self) -> bool:
         try:
-            return type(self.value) is _DynamicTick
+            return isinstance(self.value, _DynamicTick)
         except ValueError:
             return False
 
@@ -585,7 +585,7 @@ class ExpressionParser:
             value = self.fun.emulator if self.fun.emulator is not None else expr.id
             return Expression(value)
 
-        if type(expr.ctx) is not ast.Load:
+        if not isinstance(expr.ctx, ast.Load):
             # local variable, left-hand side
             return Expression(LocalVariable(expr.id))
 
@@ -603,6 +603,7 @@ class ExpressionParser:
             # parameter of the per-tick script function
             return Expression(_Operation(op_str=expr.id, dtype=self.fun.args_annotations[expr.id]))
 
+        # pylint: disable-next=eval-used
         value = eval(expr.id, self.fun.closure_vars.globals, self.fun.closure_vars.nonlocals)  # type: ignore[arg-type]
         return Expression(value)
 
@@ -632,7 +633,7 @@ class ExpressionParser:
         val = self.expression(expr.value)
         item = self.expression(expr.slice)
 
-        if type(expr.ctx) is ast.Load:
+        if isinstance(expr.ctx, ast.Load):
             v = val.value[item.value]
             return Expression(v)
 
@@ -657,7 +658,7 @@ class ExpressionParser:
         val = self.expression(expr.value)
         attr = expr.attr
 
-        if type(expr.ctx) is ast.Load:
+        if isinstance(expr.ctx, ast.Load):
             v = getattr(val.value, attr)
             return Expression(v)
 
@@ -1007,7 +1008,7 @@ class CaseExpressionParser(ExpressionParser):
         def get_if_expr(first, second):
             if isinstance(expr.op, ast.Or):
                 return ast.IfExp(test=first, body=first, orelse=second)
-            if isinstance(expr.op, ast.And):
+            else:
                 return ast.IfExp(test=first, body=second, orelse=first)
 
         first = None
