@@ -24,7 +24,7 @@ from onetick.py.core._source.tmp_otq import TmpOtq
 from onetick.py.core.column import _Column
 from onetick.py.core.column_operations.base import _Operation, OnetickParameter
 from onetick.py.core.query_inspector import get_query_parameter_list
-from onetick.py.utils import adaptive, adaptive_to_default, default
+from onetick.py.utils import adaptive, adaptive_to_default, default, render_otq
 
 
 def _is_dict_required(symbols):
@@ -939,6 +939,76 @@ class Source:
         kwargs.setdefault('verbose', True)
         self.to_graph().render(**kwargs)
 
+    def render_otq(
+        self,
+        image_path: Optional[str] = None,
+        output_format: Optional[str] = None,
+        load_external_otqs: bool = True,
+        view: bool = False,
+        line_limit: Optional[Tuple[int, int]] = (10, 30),
+        parse_eval_from_params: bool = False,
+        debug: bool = False,
+        **kwargs,
+    ):
+        """
+        Render current :py:class:`~onetick.py.Source` graph.
+
+        Parameters
+        ----------
+        image_path: str, None
+            Path for generated image. If omitted, image will be saved in a temp dir
+        output_format: str, None
+            `Graphviz` rendering format. Default: `png`.
+            If `image_path` contains one of next extensions, `output_format` will be set automatically:
+            `png`, `svg`, `dot`.
+        load_external_otqs: bool
+            If set to `True` (default) dependencies from external .otq files (not listed in ``path`` param)
+            will be loaded automatically.
+        view: bool
+            Defines should generated image be shown after render.
+        line_limit: Tuple[int, int], None
+            Limit for maximum number of lines and length of some EP parameters strings.
+            First param is limit of lines, second - limit of characters in each line.
+            If set to None limit disabled.
+            If one of tuple values set to zero the corresponding limit disabled.
+        parse_eval_from_params: bool
+            Enable parsing and printing `eval` sub-queries from EP parameters.
+        debug: bool
+            Allow to print stdout or stderr from `Graphviz` render.
+        kwargs:
+            Additional arguments to be passed to :py:meth:`onetick.py.Source.to_otq` method (except
+            ``file_name``, ``file_suffix`` and ``query_name`` parameters)
+
+        Returns
+        -------
+        Path to rendered image
+
+        See also
+        --------
+        :py:func:`render_otq <onetick.py.utils.render_otq>`
+
+        Examples
+        --------
+
+        >>> data = otp.DataSource(db='US_COMP', tick_type='TRD', symbols='AAA')  # doctest: +SKIP
+        >>> data1, data2 = data[(data['PRICE'] > 50)]  # doctest: +SKIP
+        >>> data = otp.merge([data1, data2])  # doctest: +SKIP
+        >>> data.render_otq('./path/to/image.png')  # doctest: +SKIP
+
+        .. image:: ../../static/testing/images/render_otq_3.png
+        """
+
+        if {'file_name', 'file_suffix', 'query_name'} & kwargs.keys():
+            raise ValueError(
+                'It\'s not allowed to pass parameters `file_name`, `file_suffix` and `query_name` as `kwargs` '
+                'in `render_otq` method.'
+            )
+
+        otq_path = self.to_otq(**kwargs)
+        return render_otq(
+            otq_path, image_path, output_format, load_external_otqs, view, line_limit, parse_eval_from_params, debug,
+        )
+
     def copy(self, ep=None, columns=None, deep=False) -> 'Source':
         """
         Build an object with copied calculation graph.
