@@ -1,5 +1,5 @@
 import warnings
-from typing import Dict, List, Union, Iterable, Tuple, Optional, Any, Literal
+from typing import Union, Iterable, Tuple, Optional, Any, Literal
 from datetime import date as dt_date, datetime, timedelta
 
 import pandas as pd
@@ -7,7 +7,7 @@ from dateutil.tz import gettz
 
 import onetick.py as otp
 from onetick.py import configuration, utils
-from onetick.py.compatibility import is_native_plus_zstd_supported
+from onetick.py.compatibility import is_native_plus_zstd_supported, is_show_db_list_show_description_supported
 from onetick.py.core import db_constants
 from onetick.py.otq import otq
 
@@ -25,8 +25,9 @@ class DB:
     dates with data, symbols, tick schema, etc.
     """
 
-    def __init__(self, name, context=utils.default):
+    def __init__(self, name, description='', context=utils.default):
         self.name = name
+        self.description = description
         if context is utils.default or context is None:
             self.context = otp.config.context
         else:
@@ -502,7 +503,7 @@ class DB:
             return last_date
         return date
 
-    def tick_types(self, date=None, timezone=None) -> List[str]:
+    def tick_types(self, date=None, timezone=None) -> list[str]:
         """
         Returns list of tick types for the ``date``.
 
@@ -527,7 +528,7 @@ class DB:
         date = self.last_date if date is None else date
         if timezone is None:
             timezone = configuration.config.tz
-        time_params: Dict[str, Any] = {}
+        time_params: dict[str, Any] = {}
 
         if date is not None:
             time_params['start'], time_params['end'] = self._fit_date_in_acl(date, timezone=timezone)
@@ -551,7 +552,7 @@ class DB:
         min_date = min(obj[0] for obj in self._locator_date_ranges)
         return _datetime2date(min_date)
 
-    def schema(self, date=None, tick_type=None, timezone=None, check_index_file=utils.adaptive) -> Dict[str, type]:
+    def schema(self, date=None, tick_type=None, timezone=None, check_index_file=utils.adaptive) -> dict[str, type]:
         """
         Gets the schema of the database.
 
@@ -696,7 +697,7 @@ class DB:
 
         return schema
 
-    def symbols(self, date=None, timezone=None, tick_type=None, pattern='.*') -> List[str]:
+    def symbols(self, date=None, timezone=None, tick_type=None, pattern='.*') -> list[str]:
         """
         Finds a list of available symbols in the database
 
@@ -907,7 +908,9 @@ class DB:
         return df
 
 
-def databases(context=utils.default, derived=False) -> Dict[str, DB]:
+def databases(
+    context=utils.default, derived: bool = False, readable_only: bool = True, fetch_description: bool = False,
+) -> dict[str, DB]:
     """
     Gets all available databases in the ``context``
 
@@ -918,13 +921,21 @@ def databases(context=utils.default, derived=False) -> Dict[str, DB]:
         If not set then default :py:attr:`context<onetick.py.configuration.Config.context>` is used.
         See :ref:`guide about switching contexts <switching contexts>` for examples.
     derived: bool, dict
-        If False then derived databases are not returned.
-        If dict then its items used as parameters to :py:func:`~onetick.py.derived_databases`
-        If True then default parameters for :py:func:`~onetick.py.derived_databases` are used.
+        If False (default) then derived databases are not returned.
+        Otherwise derived databases names are added to the result after the non-derived databases.
+        If set to dict then its items used as parameters to :py:func:`~onetick.py.derived_databases`.
+        If set to True then default parameters for :py:func:`~onetick.py.derived_databases` are used.
+    readable_only: bool
+        If set to True (default), then return only the databases with read-access for the current user.
+        Otherwise return all databases visible from the current process.
+    fetch_description: bool
+        If set to True, retrieves descriptions for databases and puts them into ``description`` property of
+        :py:class:`~onetick.py.DB` objects in a returned dict.
 
     See also
     --------
     | **SHOW_DB_LIST** OneTick event processor
+    | **ACCESS_INFO** OneTick event processor
     | :py:func:`derived_databases`
 
     Returns
@@ -933,7 +944,48 @@ def databases(context=utils.default, derived=False) -> Dict[str, DB]:
         Dict where keys are database names and values are :class:`DB <onetick.py.db._inspection.DB>` objects
         with ``context`` specified.
     """
-    dbs = otp.run(otq.ShowDbList().tick_type("ANY"),
+    if fetch_description and not is_show_db_list_show_description_supported():
+        fetch_description = False
+
+    if readable_only:
+        node = (
+            otq.AccessInfo(info_type='DATABASES', show_for_all_users=False, deep_scan=True).tick_type('ANY')
+            >> otq.Passthrough('DB_NAME,READ_ACCESS')
+            >> otq.WhereClause(where='READ_ACCESS = 1')
+        )
+
+        if fetch_description:
+            join = otq.Join(
+                left_source='LEFT', join_type='LEFT_OUTER', join_criteria='LEFT.DB_NAME = RIGHT.DATABASE_NAME'
+            )
+
+            _ = node.set_node_name('LEFT') >> join
+            _ = (
+                otq.ShowDbList(show_description=fetch_description).tick_type('ANY')
+                >> otq.Passthrough('DATABASE_NAME,DESCRIPTION').set_node_name('RIGHT')
+                >> join
+            )
+
+            node = (
+                join >> otq.Passthrough('LEFT.DB_NAME,RIGHT.DESCRIPTION')
+                >> otq.RenameFields("LEFT.DB_NAME=DB_NAME,RIGHT.DESCRIPTION=DESCRIPTION")
+            )
+    else:
+        db_list_kwargs = {}
+        output_fields = ['DATABASE_NAME']
+        if fetch_description:
+            db_list_kwargs['show_description'] = fetch_description
+            output_fields.append('DESCRIPTION')
+
+        node = (
+            otq.ShowDbList(**db_list_kwargs).tick_type('ANY')
+            >> otq.Passthrough(','.join(output_fields))
+        )
+
+    if not fetch_description:
+        node = node >> otq.AddField('DESCRIPTION', '""')
+
+    dbs = otp.run(node,
                   symbols='LOCAL::',
                   # start and end times don't matter for this query, use some constants
                   start=db_constants.DEFAULT_START_DATE,
@@ -944,10 +996,15 @@ def databases(context=utils.default, derived=False) -> Dict[str, DB]:
     if len(dbs) == 0:
         return {}
 
-    db_list = list(dbs['DATABASE_NAME'])
-    db_dict = {db_name: DB(db_name, context=context) for db_name in db_list}
+    db_list = list(dbs['DB_NAME'] if readable_only else dbs['DATABASE_NAME'])
+    merged_db_list = list(zip(db_list, dbs['DESCRIPTION']))
+
+    db_dict = {
+        db_name: DB(db_name, description=db_description, context=context) for db_name, db_description in merged_db_list
+    }
+
     if derived:
-        kwargs = derived if isinstance(derived, dict) else {}
+        kwargs: dict = derived if isinstance(derived, dict) else {}
         kwargs.setdefault('context', context)
         db_dict.update(
             derived_databases(**kwargs)
@@ -961,7 +1018,7 @@ def derived_databases(
     selection_criteria='all',
     db=None,
     db_discovery_scope='query_host_only',
-) -> Dict[str, DB]:
+) -> dict[str, DB]:
     """
     Gets available derived databases.
 
