@@ -182,7 +182,7 @@ class _DB:
     def _format_params(params):
         res = {}
         for key, value in params.items():
-            if isinstance(value, dt.datetime):
+            if hasattr(value, 'strftime'):
                 res[key] = value.strftime("%Y%m%d%H%M%S")
             else:
                 res[key] = str(value)
@@ -280,6 +280,8 @@ class _DB:
         # because before there was no ability to get written ticks
         if kwargs.get('propagate'):
             return res
+        else:
+            return None
 
     @property
     def properties(self):
@@ -724,105 +726,6 @@ class DB(_DB):
         return self._format_params(feed)
 
 
-"""
-Keep here as example of custom databases that can be defined in client code
-
-
-P_CME = DB(
-    name="P_CME",
-    db_properties={
-        "symbology": "CTA",
-        "archive_compression_type": constants.compression_type.NATIVE_PLUS_GZIP,
-        "tick_search_max_boundary_offset_sec": 1800,
-        "tick_timestamp_type": "NANOS",
-    },
-    db_locations=[
-        {
-            "access_method": constants.access_method.SOCKET,
-            "location": "192.168.5.63:50025",
-            "start_time": datetime(year=2008, month=9, day=1),
-            "end_time": constants.DEFAULT_END_DATE,
-        }
-    ],
-)
-
-MS127 = DB(
-    name="MS127",
-    db_properties={
-        "symbology": "MSGR",
-        "ref_data_db": "REF_DATA_MS127",
-        "archive_compression_type": constants.compression_type.NATIVE_PLUS_GZIP,
-        "ignore_previous_day_corrections_on_reload": "yes",
-    },
-    db_locations=[
-        {
-            "access_method": constants.access_method.SOCKET,
-            "location": "192.168.5.63:50025",
-            "start_time": datetime(year=2010, month=12, day=31),
-            "end_time": constants.DEFAULT_END_DATE,
-        }
-    ],
-)
-
-MS44 = DB(
-    name="MS44",
-    db_properties={
-        "symbology": "MSGR",
-        "ref_data_db": "REF_DATA_MS44",
-        "archive_compression_type": constants.compression_type.NATIVE_PLUS_GZIP,
-        "ignore_previous_day_corrections_on_reload": "yes",
-    },
-    db_locations=[
-        {
-            "access_method": constants.access_method.SOCKET,
-            "location": "192.168.5.63:50025",
-            "start_time": datetime(year=2010, month=12, day=31),
-            "end_time": constants.DEFAULT_END_DATE,
-        }
-    ],
-)
-
-TAQ_NBBO = DB(
-    name="TAQ_NBBO",
-    db_properties={
-        "symbology": "BZX",
-        "price_not_key": True,
-        "memory_data_max_life_hours": 30,
-        "memory_db_dir": "/onetick-tickdata-com/STORAGE_GATEWAY/DEEP_HISTORY/US_TED/NBBO/shmem",
-        "mmap_db_compression_type": constants.compression_type.NATIVE_PLUS_GZIP,
-    },
-    db_locations=[
-        {
-            "access_method": constants.access_method.FILE,
-            "location": "/onetick-tickdata-com/STORAGE_GATEWAY/DEEP_HISTORY/US_TED/NBBO/",
-            "start_time": datetime(year=2001, month=1, day=1),
-            "end_time": constants.DEFAULT_END_DATE,
-        }
-    ],
-)
-
-
-US_COMP = DB(
-    name="US_COMP",
-    db_properties={
-        "symbology": "BZX",
-        "price_not_key": True,
-        "memory_data_max_life_hours": 30,
-        "memory_db_dir": "/onetick-tickdata-com/STORAGE_GATEWAY/DEEP_HISTORY/US_TED/TAQ/shmem",
-        "mmap_db_compression_type": constants.compression_type.NATIVE_PLUS_GZIP,
-    },
-    db_locations=[
-        {
-            "access_method": constants.access_method.FILE,
-            "location": "/onetick-tickdata-com/STORAGE_GATEWAY/DEEP_HISTORY/US_TED/TAQ/",
-            "start_time": datetime(year=2003, month=10, day=1),
-            "end_time": constants.DEFAULT_END_DATE,
-        }
-    ],
-)
-"""
-
-
 class RefDB(DB):
     """ Creates reference database object.
 
@@ -1414,6 +1317,7 @@ class RefDB(DB):
             },
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
+            check=False,
         )
         return p.stdout, p.stderr
 
