@@ -572,6 +572,7 @@ def _add_node_name_prefix_to_columns_in_operation(op, src):
                 raise ValueError('You set to use name for column prefix, but name is empty')
             name = f'{src.node_name()}.{column.name}'
             return Column(name, column.dtype, column.obj_ref, precision=getattr(column, "_precision", None))
+        return None
 
     return op._replace_parameters(fun)
 
@@ -902,8 +903,18 @@ def join_by_time(sources, how="outer", on=None, policy=None, check_schema=True,
     0 2003-12-01 00:00:00.001  1  0
     1 2003-12-01 00:00:00.003  2  1
 
-    In case you willing to add prefix/suffix to all columns in one of the sources you should use
-    :func:`Source.add_prefix` or :func:`Source.add_suffix`
+    Note
+    ----
+    In case different ``sources`` have matching columns, the exception will be raised.
+
+    To fix this error,
+    functions :func:`Source.add_prefix` or :func:`Source.add_suffix` can be used to rename all columns in the source.
+
+    Note that resulting **TIMESTAMP** pseudo-column will be taken from the leading source,
+    and timestamps of ticks from non-leading sources will not be added to the output,
+    so if you need to save them, you need to copy the timestamp to some other column.
+
+    See examples below.
 
     Parameters
     ----------
@@ -1047,7 +1058,8 @@ def join_by_time(sources, how="outer", on=None, policy=None, check_schema=True,
 
     Default joining logic, outer join with the first source is the leader by default:
 
-    >>> otp.run(otp.join_by_time([d1, d2]))
+    >>> data = otp.join_by_time([d1, d2])
+    >>> otp.run(data)
                          Time  A  B
     0 2003-12-01 00:00:00.001  1  0
     1 2003-12-01 00:00:00.002  2  1
@@ -1055,7 +1067,8 @@ def join_by_time(sources, how="outer", on=None, policy=None, check_schema=True,
 
     Leading source can be changed by using parameter ``leading``:
 
-    >>> otp.run(otp.join_by_time([d1, d2], leading=1))
+    >>> data = otp.join_by_time([d1, d2], leading=1)
+    >>> otp.run(data)
                          Time  A  B
     0 2003-12-01 00:00:00.001  1  1
     1 2003-12-01 00:00:00.002  2  2
@@ -1064,7 +1077,8 @@ def join_by_time(sources, how="outer", on=None, policy=None, check_schema=True,
     Note that OneTick's logic is different depending on the order of sources specified,
     so specifying ``leading`` parameter in the previous example is not the same as changing the order of sources here:
 
-    >>> otp.run(otp.join_by_time([d2, d1], leading=0))
+    >>> data = otp.join_by_time([d2, d1], leading=0)
+    >>> otp.run(data)
                          Time  B  A
     0 2003-12-01 00:00:00.001  1  0
     1 2003-12-01 00:00:00.002  2  1
@@ -1073,7 +1087,8 @@ def join_by_time(sources, how="outer", on=None, policy=None, check_schema=True,
     Parameter ``source_fields_order`` can be used to change the order of fields in the output,
     but it also affects the joining logic the same way as changing the order of sources:
 
-    >>> otp.run(otp.join_by_time([d1, d2], leading=1, source_fields_order=[1, 0]))
+    >>> data = otp.join_by_time([d1, d2], leading=1, source_fields_order=[1, 0])
+    >>> otp.run(data)
                          Time  B  A
     0 2003-12-01 00:00:00.001  1  0
     1 2003-12-01 00:00:00.002  2  1
@@ -1082,26 +1097,48 @@ def join_by_time(sources, how="outer", on=None, policy=None, check_schema=True,
     Parameter ``how`` can be set to "inner".
     In this case only ticks that were successfully joined from all sources will be propagated:
 
-    >>> otp.run(otp.join_by_time([d1, d2], how='inner'))
+    >>> data = otp.join_by_time([d1, d2], how='inner')
+    >>> otp.run(data)
                          Time  A  B
     0 2003-12-01 00:00:00.002  2  1
     1 2003-12-01 00:00:00.003  3  2
 
     Set parameter ``match_if_identical_times`` to only join ticks with the same timestamps:
 
-    >>> otp.run(otp.join_by_time([d1, d2], how='inner', match_if_identical_times=True))
+    >>> data = otp.join_by_time([d1, d2], how='inner', match_if_identical_times=True)
+    >>> otp.run(data)
                          Time  A  B
     0 2003-12-01 00:00:00.001  1  1
     1 2003-12-01 00:00:00.002  2  2
 
-    Adding prefix to right source for all columns:
+    In case of conflicting names in different sources, exception will be raised:
 
-    >>> otp.run(otp.join_by_time([d1, d2.add_prefix('right_')]))
-                         Time  A  right_B
+    >>> d3 = otp.Ticks({'A': [1, 2, 4], 'offset': [1, 2, 4]})
+    >>> data = otp.join_by_time([d1, d3])
+    Traceback (most recent call last):
+        ...
+    ValueError: There are matched columns between sources: A
+
+    Adding prefix to right source for all columns will fix this problem:
+
+    >>> data = otp.join_by_time([d1, d3.add_prefix('right_')])
+    >>> otp.run(data)
+                         Time  A  right_A
     0 2003-12-01 00:00:00.001  1        0
     1 2003-12-01 00:00:00.002  2        1
     2 2003-12-01 00:00:00.003  3        2
 
+    Note that timestamps from the non-leading source are not added to the output.
+    You can add them manually in a different field:
+
+    >>> d3['D3_TIMESTAMP'] = d3['TIMESTAMP']
+    >>> data = otp.join_by_time([d1, d3.add_prefix('right_')])
+    >>> otp.run(data)
+                         Time  A  right_A      right_D3_TIMESTAMP
+    0 2003-12-01 00:00:00.001  1        0 1969-12-31 19:00:00.000
+    1 2003-12-01 00:00:00.002  2        1 2003-12-01 00:00:00.001
+    2 2003-12-01 00:00:00.003  3        2 2003-12-01 00:00:00.002
+
     Use parameter ``output_type_index`` to specify which input class to use to create output object.
     It may be useful in case some custom user class was used as input:
 
