@@ -1,7 +1,6 @@
 import ctypes
 import functools
 import inspect
-import os
 import warnings
 from typing import Optional, Type, Union
 from packaging.version import parse as parse_version
@@ -520,7 +519,7 @@ class _inner_string(type):
     @functools.lru_cache(maxsize=None)  # noqa: W1518
     def __getitem__(cls, item):
 
-        if (type(item) is not int or item < 1) and item is not Ellipsis:
+        if (not isinstance(item, int) or item < 1) and item is not Ellipsis:
             raise TypeError("It is not allowed to have non numeric index")
 
         class _inner_str(string):  # type: ignore[misc]
@@ -847,6 +846,7 @@ def get_object_type(obj):
         return dtype
     if is_time_type(obj):
         return nsectime
+    # pylint: disable-next=unidiomatic-typecheck
     if type(obj) is int and obj > long.MAX:
         # by default we use python's int (onetick's long) for numbers
         # in case the number is too big, let's use onetick's ulong
@@ -917,6 +917,7 @@ def get_type_by_objects(objs):
         dtype = nsectime
 
     # we assume the None value has float default value, ie NaN
+    # pylint: disable-next=unidiomatic-typecheck
     if type(None) is dtype:
         dtype = float
 
@@ -1271,7 +1272,7 @@ class datetime(AbstractTime):
         return result
 
     def _error_on_int_param(self, other, op):
-        if type(other) is int:
+        if isinstance(other, int):
             raise TypeError(f"unsupported operand type(s) for {op}: 'otp.datetime' and 'int'")
 
     def __str__(self):
@@ -1735,7 +1736,7 @@ def str2type(type_name: str):
 
 def type2np(t):
     if issubclass(t, str):
-        if issubclass(t, otp.string) and type(t.length) is int:
+        if issubclass(t, otp.string) and isinstance(t.length, int):
             return '<U' + str(t.length)
         return '<U64'
     elif issubclass(t, bool):
@@ -1774,27 +1775,27 @@ def type2np(t):
 
 # TODO: move this union of types to some common place
 def datetime2expr(
-    dt: Union[_datetime, _date, pd.Timestamp, date, datetime],
+    dt_obj: Union[_datetime, _date, pd.Timestamp, date, datetime],
     timezone: Optional[str] = None,
     timezone_naive: Optional[str] = None,
 ) -> str:
     """
     Convert python datetime values to OneTick string representation.
-    If `dt` is timezone-aware then timezone will be taken from `dt` value.
-    If `dt` is timezone-naive then timezone specified with otp.config['tz'] or otp.run() will be used.
+    If ``dt_obj`` is timezone-aware then timezone will be taken from ``dt_obj`` value.
+    If ``dt_obj`` is timezone-naive then timezone specified with otp.config['tz'] or otp.run() will be used.
 
     Parameters
     ----------
-    dt
+    dt_obj
         date or datetime value
     timezone: str or Operation
         This timezone will be used unconditionally.
     timezone_naive: str or Operation
-        This timezone will be used if `dt` is timezone-naive.
+        This timezone will be used if ``dt_obj`` is timezone-naive.
     """
-    dt_str = _format_datetime(dt, '%Y-%m-%d %H:%M:%S.%f', add_nano_suffix=True)
+    dt_str = _format_datetime(dt_obj, '%Y-%m-%d %H:%M:%S.%f', add_nano_suffix=True)
     if timezone is None:
-        timezone = get_timezone_from_datetime(dt)
+        timezone = get_timezone_from_datetime(dt_obj)
     if timezone is None:
         timezone = timezone_naive
     if not isinstance(timezone, otp.Operation):
@@ -1802,16 +1803,16 @@ def datetime2expr(
     return f'PARSE_NSECTIME("%Y-%m-%d %H:%M:%S.%J", "{dt_str}", {str(timezone)})'
 
 
-def datetime2timeval(dt: Union[_datetime, _date, pd.Timestamp, date, datetime], timezone: str = 'GMT'):
+def datetime2timeval(dt_obj: Union[_datetime, _date, pd.Timestamp, date, datetime], timezone: str = 'GMT'):
     """
     Get nanosecond-precision pyomd.timeval_t
     from different datetime types supported by onetick-py.
 
-    If ``dt`` is timezone-aware, then its timezone will be used.
-    If ``dt`` is timezone-naive , then it will be localized to ``timezone`` parameter (GMT by default).
+    If ``dt_obj`` is timezone-aware, then its timezone will be used.
+    If ``dt_obj`` is timezone-naive , then it will be localized to ``timezone`` parameter (GMT by default).
     """
-    dt_str = _format_datetime(dt, '%Y-%m-%d %H:%M:%S.%f', add_nano_suffix=True)
-    tz_str = get_timezone_from_datetime(dt)
+    dt_str = _format_datetime(dt_obj, '%Y-%m-%d %H:%M:%S.%f', add_nano_suffix=True)
+    tz_str = get_timezone_from_datetime(dt_obj)
     if tz_str:
         # use timezone from the object
         return pyomd.TimeParser('%Y-%m-%d %H:%M:%S.%J', tz_str).parse_time(dt_str)
@@ -1820,11 +1821,11 @@ def datetime2timeval(dt: Union[_datetime, _date, pd.Timestamp, date, datetime],
         return pyomd.TimeParser('%Y-%m-%d %H:%M:%S.%J', timezone).parse_time(dt_str)
 
 
-def _format_datetime(dt, fmt, add_nano_suffix=True):
-    dt_str = dt.strftime(fmt)
+def _format_datetime(dt_obj, fmt, add_nano_suffix=True):
+    dt_str = dt_obj.strftime(fmt)
     if add_nano_suffix:
-        if isinstance(dt, (pd.Timestamp, datetime)):
-            dt_str += f'{dt.nanosecond:03}'[-3:]
+        if isinstance(dt_obj, (pd.Timestamp, datetime)):
+            dt_str += f'{dt_obj.nanosecond:03}'[-3:]
         else:
             dt_str += '000'
     return dt_str
@@ -1933,15 +1934,15 @@ def is_time_type(time):
     return issubclass(time, (_date, datetime, date))
 
 
-def next_day(dt: Union[_date, _datetime, date, datetime, pd.Timestamp]) -> _datetime:
+def next_day(dt_obj: Union[_date, _datetime, date, datetime, pd.Timestamp]) -> _datetime:
     """
-    Return next day of `dt` as datetime.datetime.
+    Return next day of ``dt_obj`` as datetime.datetime.
     """
-    updated_dt = dt + Day(1)
+    updated_dt = dt_obj + Day(1)
 
     # If we switch ts on timezone transition time, ts changes its timezone offset
-    if hasattr(dt, "tzinfo") and updated_dt.tzinfo != dt.tzinfo:
-        dt_offset = dt.tzinfo.utcoffset(dt)
+    if hasattr(dt_obj, "tzinfo") and updated_dt.tzinfo != dt_obj.tzinfo:
+        dt_offset = dt_obj.tzinfo.utcoffset(dt_obj)
         updated_dt_offset = updated_dt.tzinfo.utcoffset(updated_dt)
 
         tz_diff = dt_offset - updated_dt_offset
@@ -2005,6 +2006,7 @@ def default_by_type(dtype):
         return dtype('')
     if issubclass(dtype, nsectime) or issubclass(dtype, msectime):
         return dtype(0)
+    raise TypeError(f"Can't get default value for type: {dtype}")
 
 
 class timedelta(pd.Timedelta):
