@@ -20,6 +20,7 @@ EPS_WITH_QUERIES = {
     "modify_state_var_from_query": (1, "otq_query"),
     "create_cache": (1, "otq_file_path"),
     "read_cache": (4, "create_cache_query"),
+    "generic_aggregation": (0, "query_name"),
 }
 
 IF_ELSE_EPS = {
@@ -341,7 +342,10 @@ def _parse_function_params(func_params: str) -> Tuple[list, dict]:
 
 
 def _parse_function(expression: str) -> Tuple[Optional[str], list, dict]:
-    m = re.search(r"^(\w*)\s*\(([\s\S]*)\)\s*$", expression)
+    # EP_NAME(PARAM_NAME=PARAM_VALUE,...)
+    # [a-zA-Z_:] is EP_NAME, can contain letters, underscore and colon
+    # [\s\S] is any symbol including newline (because . doesn't include newline by default)
+    m = re.search(r"^([a-zA-Z_:]*)\s*\(([\s\S]*)\)\s*$", expression)
 
     if not m:
         return None, [], {}
@@ -500,20 +504,24 @@ def _build_query_tree(query: Query):
             node.labels["OUT"] = node.config["NESTED_OUTPUT"]
 
         if "SOURCE_DESCRIPTION" in node.config:
-            description = node.config["SOURCE_DESCRIPTION"].strip().split(" ")
-            if len(description) > 1:
-                desc_node = description[0].split(".")[0]
-                labels = description[1].split(".")
+            descriptions = node.config["SOURCE_DESCRIPTION"]
+            if isinstance(descriptions, str):
+                descriptions = [descriptions]
+            for description in descriptions:
+                description = description.strip().split(" ")
+                if len(description) > 1:
+                    desc_node = description[0].split(".")[0]
+                    labels = description[1].split(".")
 
-                if labels and desc_node in query.nodes:
-                    if labels[0]:
-                        query.nodes[desc_node].labels["IN"] = labels[0]
+                    if labels and desc_node in query.nodes:
+                        if labels[0]:
+                            query.nodes[desc_node].labels["IN"] = labels[0]
 
-                    if labels[1]:
-                        query.nodes[desc_node].labels["OUT"] = labels[1]
+                        if labels[1]:
+                            query.nodes[desc_node].labels["OUT"] = labels[1]
 
         if "SINK_DESCRIPTION" in node.config:
-            description_path = node.config["SOURCE_DESCRIPTION"].strip().split(".")
+            description_path = node.config["SINK_DESCRIPTION"].strip().split(".")
             if len(description_path) > 1:
                 desc_node = description_path[0]
                 label = description_path[-1]
@@ -526,7 +534,7 @@ def _build_query_tree(query: Query):
         if "SINK" in node.config:
             sink_nodes = [(sink, True) for sink in node.config["SINK"].strip().split()]
             if sink_nodes:
-                leaves.remove(node_id)
+                leaves.discard(node_id)
 
             nodes += sink_nodes
             del node.config["SINK"]
@@ -534,7 +542,7 @@ def _build_query_tree(query: Query):
         if "SOURCE" in node.config:
             source_nodes = [(sink, False) for sink in node.config["SOURCE"].strip().split()]
             if source_nodes:
-                roots.remove(node_id)
+                roots.discard(node_id)
 
             nodes += source_nodes
             del node.config["SOURCE"]
@@ -545,10 +553,10 @@ def _build_query_tree(query: Query):
             source_node_id = source_node_path[0]
 
             if not is_sink_node and source_node_id in leaves:
-                leaves.remove(source_node_id)
+                leaves.discard(source_node_id)
 
             if is_sink_node and source_node_id in roots:
-                roots.remove(source_node_id)
+                roots.discard(source_node_id)
 
             if source_node_id not in query.nodes:
                 raise RuntimeError(f"Malformed otq file passed: node {source_node_id} not found in {query.name}")
@@ -689,21 +697,25 @@ def read_otq(path: str, parse_eval_from_params: bool = False) -> Optional[Graph]
     return graph
 
 
-def filter_nodes(ep: Any, param, value, line_limit: Optional[Tuple[int, int]] = None):
-    if line_limit is not None and (line_limit[0] < 0 or line_limit[1] < 0):
+def truncate_param_value(ep: Any, param, value, line_limit: Optional[Tuple[int, int]] = None):
+    if line_limit is None:
+        return value
+
+    height, width = line_limit
+    if height < 0 or width < 0:
         raise ValueError("line_limit values should not be negative")
 
-    if isinstance(ep, EP) and line_limit is not None and (
+    if isinstance(ep, EP) and (
         ep.name == "PER_TICK_SCRIPT" and param.lower() == "script" or
         ep.name == "CSV_FILE_LISTING" and param.lower() == "file_contents"
     ):
         lines = [
-            line if len(line) <= line_limit[1] or not line_limit[1] else line[:line_limit[1]] + "..."
+            line if len(line) <= width or not width else line[:width] + "..."
             for line in value.split("\n")
         ]
 
-        if line_limit[0] and len(lines) > line_limit[0]:
-            lines = lines[:line_limit[0]] + ["..."]
+        if height and len(lines) > height:
+            lines = lines[:height] + ["..."]
 
         return "\n".join(lines)
 
@@ -790,11 +802,13 @@ def build_node(graphs: GraphStorage, node: Node, line_limit: Optional[Tuple[int,
                 attrs["sides"] = "LR"
 
             if isinstance(v, NestedQuery):
-                param_value = html.escape(v.raw_string)
+                param_value = v.raw_string
             else:
-                param_value = html.escape(v).replace("\t", "&nbsp;" * 4)
+                param_value = v
 
-            param_lines = filter_nodes(node.ep, k, param_value, line_limit).split("\n")
+            param_value = truncate_param_value(node.ep, k, param_value, line_limit)
+            param_value = html.escape(param_value).replace("\t", "&nbsp;" * 4)
+            param_lines = param_value.split("\n")
 
             if k:
                 if len(param_lines) == 1:
@@ -1018,10 +1032,10 @@ def render_otq(
         `Graphviz` rendering format. Default: `png`.
         If `image_path` contains one of next extensions, `output_format` will be set automatically: `png`, `svg`, `dot`.
     load_external_otqs: bool
-        If set to `True` (default) dependencies from external .otq files (not listed in `path` param)
+        If set to `True` (default) dependencies from external .otq files (not listed in ``path`` param)
         will be loaded automatically.
     view: bool
-        Defines should generated image be showed after render.
+        Defines should generated image be shown after render.
     line_limit: Tuple[int, int], None
         Limit for maximum number of lines and length of some EP parameters strings.
         First param is limit of lines, second - limit of characters in each line.
@@ -1030,7 +1044,11 @@ def render_otq(
     parse_eval_from_params: bool
         Enable parsing and printing `eval` sub-queries from EP parameters.
     debug: bool
-        Allow to print stdout or stderr from `Grapthviz` render.
+        Allow to print stdout or stderr from `Graphviz` render.
+
+    Returns
+    -------
+    Path to rendered image
 
     Examples
     --------
@@ -1039,10 +1057,14 @@ def render_otq(
 
     >>> otp.utils.render_otq("./test.otq")  # doctest: +SKIP
 
+    .. image:: ../../static/testing/images/render_otq_1.png
+
     Render multiple files:
 
     >>> otp.utils.render_otq(["./first.otq", "./second.otq"])  # doctest: +SKIP
 
+    .. image:: ../../static/testing/images/render_otq_2.png
+
     Render specific queries from multiple files:
 
     >>> otp.utils.render_otq(["./first.otq", "./second.otq::some_query"])  # doctest: +SKIP
